==> jc-1.4.0.tar.gz: soot/baf/InstBox.h <==
// class soot.baf.InstBox

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5cec03cf39985907 soot_AbstractUnitBox
// @dep_class 8c7d51d2dce9cce9 soot_baf_InstBox

// header file dependencies
// @dep_header soot_AbstractUnitBox

#include "soot/AbstractUnitBox.h"

#ifndef _JC_soot_baf_InstBox_H_
#define _JC_soot_baf_InstBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Unit$object;
struct _jc_soot_baf_Inst$object;

// Typedefs
typedef struct _jc_soot_baf_InstBox$sub_refs	_jc_soot_baf_InstBox$sub_refs;
typedef struct _jc_soot_baf_InstBox$sub_nonrefs	_jc_soot_baf_InstBox$sub_nonrefs;
typedef struct _jc_soot_baf_InstBox$refs	_jc_soot_baf_InstBox$refs;
typedef struct _jc_soot_baf_InstBox$nonrefs	_jc_soot_baf_InstBox$nonrefs;
typedef struct _jc_soot_baf_InstBox$object	_jc_soot_baf_InstBox$object;

typedef const struct _jc_soot_baf_InstBox$vmethods	_jc_soot_baf_InstBox$vmethods;
typedef const struct _jc_soot_baf_InstBox$vtable	_jc_soot_baf_InstBox$vtable;
typedef const struct _jc_soot_baf_InstBox$vtype	_jc_soot_baf_InstBox$vtype;

// Constructors
extern void _jc_soot_baf_InstBox$method$_init$d2b864984a518590(_jc_env *, struct _jc_soot_baf_InstBox$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_baf_InstBox$method$canContainUnit$081e9f3eeb61f46c(_jc_env *, struct _jc_soot_baf_InstBox$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_InstBox$method_info$canContainUnit$081e9f3eeb61f46c;

// Virtual methods structure
struct _jc_soot_baf_InstBox$vmethods {
	jboolean	(*canContainUnit$081e9f3eeb61f46c)(_jc_env *, struct _jc_soot_baf_InstBox$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_baf_InstBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractUnitBox$vmethods	soot_AbstractUnitBox;
	_jc_soot_baf_InstBox$vmethods	soot_baf_InstBox;
};

// Vtype
struct _jc_soot_baf_InstBox$vtype {
	_jc_type			type;
	_jc_soot_baf_InstBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_InstBox$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_InstBox$refs {
    _jc_soot_baf_InstBox$sub_refs	soot_baf_InstBox;
    _jc_soot_AbstractUnitBox$sub_refs	soot_AbstractUnitBox;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_InstBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_InstBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractUnitBox$sub_nonrefs	soot_AbstractUnitBox;
    _jc_soot_baf_InstBox$sub_nonrefs	soot_baf_InstBox;
};

// Object instance structure
struct _jc_soot_baf_InstBox$object {
	_jc_soot_baf_InstBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_InstBox$vtype	*vtype;
	_jc_soot_baf_InstBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_InstBox$vtype _jc_soot_baf_InstBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_InstBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_InstBox$class_object;

#endif	/* _JC_soot_baf_InstBox_H_ */

==> jc-1.4.6.tar.gz: soot/baf/InstBox.h <==
// class soot.baf.InstBox

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5cec03cf39985907 soot_AbstractUnitBox
// @dep_class 8c7d51d2dce9cce9 soot_baf_InstBox

// header file dependencies
// @dep_header soot_AbstractUnitBox

#include "soot/AbstractUnitBox.h"

#ifndef _JC_soot_baf_InstBox_H_
#define _JC_soot_baf_InstBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Unit$object;
struct _jc_soot_baf_Inst$object;

// Typedefs
typedef struct _jc_soot_baf_InstBox$sub_refs	_jc_soot_baf_InstBox$sub_refs;
typedef struct _jc_soot_baf_InstBox$sub_nonrefs	_jc_soot_baf_InstBox$sub_nonrefs;
typedef struct _jc_soot_baf_InstBox$refs	_jc_soot_baf_InstBox$refs;
typedef struct _jc_soot_baf_InstBox$nonrefs	_jc_soot_baf_InstBox$nonrefs;
typedef struct _jc_soot_baf_InstBox$object	_jc_soot_baf_InstBox$object;

typedef const struct _jc_soot_baf_InstBox$vmethods	_jc_soot_baf_InstBox$vmethods;
typedef const struct _jc_soot_baf_InstBox$vtable	_jc_soot_baf_InstBox$vtable;
typedef const struct _jc_soot_baf_InstBox$vtype	_jc_soot_baf_InstBox$vtype;

// Constructors
extern void _jc_soot_baf_InstBox$method$_init$d2b864984a518590(_jc_env *, struct _jc_soot_baf_InstBox$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_baf_InstBox$method$canContainUnit$081e9f3eeb61f46c(_jc_env *, struct _jc_soot_baf_InstBox$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_InstBox$method_info$canContainUnit$081e9f3eeb61f46c;

// Virtual methods structure
struct _jc_soot_baf_InstBox$vmethods {
	jboolean	(*canContainUnit$081e9f3eeb61f46c)(_jc_env *, struct _jc_soot_baf_InstBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_InstBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractUnitBox$vmethods	soot_AbstractUnitBox;
	_jc_soot_baf_InstBox$vmethods	soot_baf_InstBox;
};

// Vtype
struct _jc_soot_baf_InstBox$vtype {
	_jc_type			type;
	_jc_soot_baf_InstBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_InstBox$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_InstBox$refs {
    _jc_soot_baf_InstBox$sub_refs	soot_baf_InstBox;
    _jc_soot_AbstractUnitBox$sub_refs	soot_AbstractUnitBox;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_InstBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_InstBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractUnitBox$sub_nonrefs	soot_AbstractUnitBox;
    _jc_soot_baf_InstBox$sub_nonrefs	soot_baf_InstBox;
};

// Object instance structure
struct _jc_soot_baf_InstBox$object {
	_jc_soot_baf_InstBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_InstBox$vtype	*vtype;
	_jc_soot_baf_InstBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_InstBox$vtype _jc_soot_baf_InstBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_InstBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_InstBox$class_object;

#endif	/* _JC_soot_baf_InstBox_H_ */
